pub struct ConsensusEngineHandle<Payload>where
Payload: PayloadTypes,{ /* private fields */ }Expand description
A cloneable sender type that can be used to send engine API messages.
This type mirrors consensus related functions of the engine API.
Implementations
Sourceimpl<Payload> ConsensusEngineHandle<Payload>where
Payload: PayloadTypes,
impl<Payload> ConsensusEngineHandle<Payload>where
Payload: PayloadTypes,
Sourcepub const fn new(
to_engine: UnboundedSender<BeaconEngineMessage<Payload>>,
) -> ConsensusEngineHandle<Payload>
pub const fn new( to_engine: UnboundedSender<BeaconEngineMessage<Payload>>, ) -> ConsensusEngineHandle<Payload>
Creates a new beacon consensus engine handle.
Sourcepub async fn new_payload(
&self,
payload: <Payload as PayloadTypes>::ExecutionData,
) -> Result<PayloadStatus, BeaconOnNewPayloadError>
pub async fn new_payload( &self, payload: <Payload as PayloadTypes>::ExecutionData, ) -> Result<PayloadStatus, BeaconOnNewPayloadError>
Sends a new payload message to the beacon consensus engine and waits for a response.
Sourcepub async fn reth_new_payload(
&self,
payload: <Payload as PayloadTypes>::ExecutionData,
) -> Result<(PayloadStatus, NewPayloadTimings), BeaconOnNewPayloadError>
pub async fn reth_new_payload( &self, payload: <Payload as PayloadTypes>::ExecutionData, ) -> Result<(PayloadStatus, NewPayloadTimings), BeaconOnNewPayloadError>
Sends a new payload message used by reth_newPayload endpoint.
Waits for persistence, execution cache, and sparse trie locks before processing, and returns detailed timing breakdown alongside the payload status.
Sourcepub async fn fork_choice_updated(
&self,
state: ForkchoiceState,
payload_attrs: Option<<Payload as PayloadTypes>::PayloadAttributes>,
version: EngineApiMessageVersion,
) -> Result<ForkchoiceUpdated, BeaconForkChoiceUpdateError>
pub async fn fork_choice_updated( &self, state: ForkchoiceState, payload_attrs: Option<<Payload as PayloadTypes>::PayloadAttributes>, version: EngineApiMessageVersion, ) -> Result<ForkchoiceUpdated, BeaconForkChoiceUpdateError>
Sends a forkchoice update message to the beacon consensus engine and waits for a response.